@@ -213,7 +213,7 @@ namespace Microsoft.BaseTypes
     }
 
     [Pure]
-    public override string /*!*/ ToString()
+    public override string ToString()
     {
       Contract.Ensures(Contract.Result<string>() != null);
       if (value == "")
