@@ -148,13 +148,13 @@ namespace Microsoft.Boogie
     public byte[] SugaredCmdChecksum { get; internal set; }
     public bool IrrelevantForChecksumComputation { get; set; }
 
-    public Cmd(IToken /*!*/ tok)
+    public Cmd(IToken tok)
       : base(tok)
     {
       Contract.Assert(tok != null);
     }
 
-    public abstract void Emit(TokenTextWriter /*!*/ stream, int level);
+    public abstract void Emit(TokenTextWriter stream, int level);
 
     /// <summary>
     /// Should only be called after resolution
@@ -165,13 +165,13 @@ namespace Microsoft.Boogie
       return ids.Select(id => id.Decl);
     }
     
-    public abstract void AddAssignedIdentifiers(List<IdentifierExpr> /*!*/ vars);
+    public abstract void AddAssignedIdentifiers(List<IdentifierExpr> vars);
 
     public void CheckAssignments(TypecheckingContext tc)
     {
       Contract.Requires(tc != null);
-      var /*!*/ vars = GetAssignedVariables().ToList();
-      foreach (Variable /*!*/ v in vars)
+      var vars = GetAssignedVariables().ToList();
+      foreach (Variable v in vars)
       {
         Contract.Assert(v != null);
         if (!v.IsMutable)
@@ -197,10 +197,10 @@ namespace Microsoft.Boogie
       Contract.Requires(lhs != null);
       Contract.Requires(tok != null);
       Contract.Ensures(Contract.Result<AssignCmd>() != null);
-      List<AssignLhs /*!*/> /*!*/
-        lhss = new List<AssignLhs /*!*/>();
-      List<Expr /*!*/> /*!*/
-        rhss = new List<Expr /*!*/>();
+      List<AssignLhs>
+        lhss = new List<AssignLhs>();
+      List<Expr>
+        rhss = new List<Expr>();
 
       lhss.Add(new SimpleAssignLhs(lhs.tok, lhs));
       rhss.Add(rhs);
@@ -208,21 +208,21 @@ namespace Microsoft.Boogie
       return new AssignCmd(tok, lhss, rhss);
     }
 
-    public static AssignCmd /*!*/ MapAssign(IToken tok,
-      IdentifierExpr /*!*/ map,
-      List<Expr> /*!*/ indexes, Expr /*!*/ rhs)
+    public static AssignCmd MapAssign(IToken tok,
+      IdentifierExpr map,
+      List<Expr> indexes, Expr rhs)
     {
       Contract.Requires(tok != null);
       Contract.Requires(map != null);
       Contract.Requires(indexes != null);
       Contract.Requires(rhs != null);
       Contract.Ensures(Contract.Result<AssignCmd>() != null);
-      List<AssignLhs /*!*/> /*!*/
-        lhss = new List<AssignLhs /*!*/>();
-      List<Expr /*!*/> /*!*/
-        rhss = new List<Expr /*!*/>();
-      List<Expr /*!*/> /*!*/
-        indexesList = new List<Expr /*!*/>();
+      List<AssignLhs>
+        lhss = new List<AssignLhs>();
+      List<Expr>
+        rhss = new List<Expr>();
+      List<Expr>
+        indexesList = new List<Expr>();
 
 
       foreach (Expr e in indexes)
@@ -238,9 +238,9 @@ namespace Microsoft.Boogie
       return new AssignCmd(tok, lhss, rhss);
     }
 
-    public static AssignCmd /*!*/ MapAssign(IToken tok,
-      IdentifierExpr /*!*/ map,
-      params Expr[] /*!*/ args)
+    public static AssignCmd MapAssign(IToken tok,
+      IdentifierExpr map,
+      params Expr[] args)
     {
       Contract.Requires(tok != null);
       Contract.Requires(map != null);
@@ -249,12 +249,12 @@ namespace Microsoft.Boogie
       Contract.Requires(Contract.ForAll(args, i => i != null));
       Contract.Ensures(Contract.Result<AssignCmd>() != null);
 
-      List<AssignLhs /*!*/> /*!*/
-        lhss = new List<AssignLhs /*!*/>();
-      List<Expr /*!*/> /*!*/
-        rhss = new List<Expr /*!*/>();
-      List<Expr /*!*/> /*!*/
-        indexesList = new List<Expr /*!*/>();
+      List<AssignLhs>
+        lhss = new List<AssignLhs>();
+      List<Expr>
+        rhss = new List<Expr>();
+      List<Expr>
+        indexesList = new List<Expr>();
 
       for (int i = 0; i < args.Length - 1; ++i)
       {
@@ -302,7 +302,7 @@ namespace Microsoft.Boogie
   
   public class CommentCmd : Cmd // just a convenience for debugging
   {
-    public readonly string /*!*/
+    public readonly string
       Comment;
 
     [ContractInvariantMethod]
@@ -440,9 +440,9 @@ namespace Microsoft.Boogie
     {
       stream.Write(this, level, "");
 
-      string /*!*/
+      string
         sep = "";
-      foreach (AssignLhs /*!*/ l in Lhss)
+      foreach (AssignLhs l in Lhss)
       {
         Contract.Assert(l != null);
         stream.Write(sep);
@@ -453,7 +453,7 @@ namespace Microsoft.Boogie
       stream.Write(" := ");
 
       sep = "";
-      foreach (Expr /*!*/ e in Rhss)
+      foreach (Expr e in Rhss)
       {
         Contract.Assert(e != null);
         stream.Write(sep);
@@ -473,13 +473,13 @@ namespace Microsoft.Boogie
           "number of left-hand sides does not match number of right-hand sides");
       }
 
-      foreach (AssignLhs /*!*/ e in Lhss)
+      foreach (AssignLhs e in Lhss)
       {
         Contract.Assert(e != null);
         e.Resolve(rc);
       }
 
-      foreach (Expr /*!*/ e in Rhss)
+      foreach (Expr e in Rhss)
       {
         Contract.Assert(e != null);
         e.Resolve(rc);
@@ -551,7 +551,7 @@ namespace Microsoft.Boogie
         expectedLayerRanges = Lhss.Select(e => e.DeepAssignedVariable.LayerRange).ToList();
       }
 
-      foreach (AssignLhs /*!*/ e in Lhss)
+      foreach (AssignLhs e in Lhss)
       {
         Contract.Assert(e != null);
         e.Typecheck(tc);
@@ -588,7 +588,7 @@ namespace Microsoft.Boogie
     }
 
     public override void AddAssignedIdentifiers(List<IdentifierExpr> vars) {
-      foreach (AssignLhs /*!*/ l in Lhss)
+      foreach (AssignLhs l in Lhss)
       {
         vars.Add(l.DeepAssignedIdentifier);
       }
@@ -597,16 +597,16 @@ namespace Microsoft.Boogie
     // transform away the syntactic sugar of map assignments and
     // determine an equivalent assignment in which all rhs are simple
     // variables
-    public AssignCmd /*!*/ AsSimpleAssignCmd
+    public AssignCmd AsSimpleAssignCmd
     {
       get
       {
         Contract.Ensures(Contract.Result<AssignCmd>() != null);
 
-        List<AssignLhs /*!*/> /*!*/
-          newLhss = new List<AssignLhs /*!*/>();
-        List<Expr /*!*/> /*!*/
-          newRhss = new List<Expr /*!*/>();
+        List<AssignLhs>
+          newLhss = new List<AssignLhs>();
+        List<Expr>
+          newRhss = new List<Expr>();
 
         for (int i = 0; i < Lhss.Count; ++i)
         {
@@ -634,24 +634,24 @@ namespace Microsoft.Boogie
     public abstract Type Type { get; }
 
     // Determine the variable that is actually assigned in this lhs
-    public abstract IdentifierExpr /*!*/ DeepAssignedIdentifier { get; }
+    public abstract IdentifierExpr DeepAssignedIdentifier { get; }
     public abstract Variable DeepAssignedVariable { get; }
 
-    public AssignLhs(IToken /*!*/ tok)
+    public AssignLhs(IToken tok)
       : base(tok)
     {
       Contract.Requires(tok != null);
     }
 
-    public abstract void Emit(TokenTextWriter /*!*/ stream);
+    public abstract void Emit(TokenTextWriter stream);
 
-    public abstract Expr /*!*/ AsExpr { get; }
+    public abstract Expr AsExpr { get; }
 
     // transform away the syntactic sugar of map assignments and
     // determine an equivalent simple assignment
-    internal abstract void AsSimpleAssignment(Expr /*!*/ rhs,
-      out IdentifierExpr /*!*/ simpleLhs,
-      out Expr /*!*/ simpleRhs);
+    internal abstract void AsSimpleAssignment(Expr rhs,
+      out IdentifierExpr simpleLhs,
+      out Expr simpleRhs);
   }
 
   [ContractClassFor(typeof(AssignLhs))]
@@ -691,7 +691,7 @@ namespace Microsoft.Boogie
 
   public class SimpleAssignLhs : AssignLhs
   {
-    public IdentifierExpr /*!*/
+    public IdentifierExpr
       AssignedVariable;
 
     [ContractInvariantMethod]
@@ -703,7 +703,7 @@ namespace Microsoft.Boogie
 
     public override Type Type => AssignedVariable.Type.Expanded;
 
-    public override IdentifierExpr /*!*/ DeepAssignedIdentifier
+    public override IdentifierExpr DeepAssignedIdentifier
     {
       get
       {
@@ -740,7 +740,7 @@ namespace Microsoft.Boogie
       AssignedVariable.Emit(stream);
     }
 
-    public override Expr /*!*/ AsExpr
+    public override Expr AsExpr
     {
       get
       {
@@ -751,8 +751,8 @@ namespace Microsoft.Boogie
     }
 
     internal override void AsSimpleAssignment(Expr rhs,
-      out IdentifierExpr /*!*/ simpleLhs,
-      out Expr /*!*/ simpleRhs)
+      out IdentifierExpr simpleLhs,
+      out Expr simpleRhs)
     {
       simpleLhs = AssignedVariable;
       simpleRhs = rhs;
@@ -769,10 +769,10 @@ namespace Microsoft.Boogie
   // things separate
   public class MapAssignLhs : AssignLhs
   {
-    public AssignLhs /*!*/
+    public AssignLhs
       Map;
 
-    public List<Expr /*!*/> /*!*/
+    public List<Expr>
       Indexes;
 
     [ContractInvariantMethod]
@@ -802,7 +802,7 @@ namespace Microsoft.Boogie
       }
     }
 
-    public override IdentifierExpr /*!*/ DeepAssignedIdentifier
+    public override IdentifierExpr DeepAssignedIdentifier
     {
       get
       {
@@ -817,7 +817,7 @@ namespace Microsoft.Boogie
       get { return Map.DeepAssignedVariable; }
     }
 
-    public MapAssignLhs(IToken tok, AssignLhs map, List<Expr /*!*/> /*!*/ indexes)
+    public MapAssignLhs(IToken tok, AssignLhs map, List<Expr> indexes)
       : base(tok)
     {
       Contract.Requires(map != null);
@@ -831,7 +831,7 @@ namespace Microsoft.Boogie
     public override void Resolve(ResolutionContext rc)
     {
       Map.Resolve(rc);
-      foreach (Expr /*!*/ e in Indexes)
+      foreach (Expr e in Indexes)
       {
         Contract.Assert(e != null);
         e.Resolve(rc);
@@ -841,16 +841,16 @@ namespace Microsoft.Boogie
     public override void Typecheck(TypecheckingContext tc)
     {
       Map.Typecheck(tc);
-      foreach (Expr /*!*/ e in Indexes)
+      foreach (Expr e in Indexes)
       {
         Contract.Assert(e != null);
         e.Typecheck(tc);
       }
 
       // we use the same typechecking code as in MapSelect
-      List<Expr> /*!*/
+      List<Expr>
         selectArgs = new List<Expr>();
-      foreach (Expr /*!*/ e in Indexes)
+      foreach (Expr e in Indexes)
       {
         Contract.Assert(e != null);
         selectArgs.Add(e);
@@ -866,9 +866,9 @@ namespace Microsoft.Boogie
     {
       Map.Emit(stream);
       stream.Write("[");
-      string /*!*/
+      string
         sep = "";
-      foreach (Expr /*!*/ e in Indexes)
+      foreach (Expr e in Indexes)
       {
         Contract.Assert(e != null);
         stream.Write(sep);
@@ -879,13 +879,13 @@ namespace Microsoft.Boogie
       stream.Write("]");
     }
 
-    public override Expr /*!*/ AsExpr
+    public override Expr AsExpr
     {
       get
       {
         Contract.Ensures(Contract.Result<Expr>() != null);
 
-        NAryExpr /*!*/
+        NAryExpr
           res = Expr.Select(Map.AsExpr, Indexes);
         Contract.Assert(res != null);
         res.TypeParameters = this.TypeParameters;
@@ -895,14 +895,13 @@ namespace Microsoft.Boogie
     }
 
     internal override void AsSimpleAssignment(Expr rhs,
-      out IdentifierExpr /*!*/ simpleLhs,
-      out Expr /*!*/ simpleRhs)
+      out IdentifierExpr simpleLhs,
+      out Expr simpleRhs)
     {
-      //Contract.Requires(rhs != null);
       Contract.Ensures(Contract.ValueAtReturn(out simpleLhs) != null);
       Contract.Ensures(Contract.ValueAtReturn(out simpleRhs) != null);
 
-      NAryExpr /*!*/
+      NAryExpr
         newRhs = Expr.Store(Map.AsExpr, Indexes, rhs);
       Contract.Assert(newRhs != null);
       newRhs.TypeParameters = this.TypeParameters;
@@ -912,7 +911,6 @@ namespace Microsoft.Boogie
 
     public override Absy StdDispatch(StandardVisitor visitor)
     {
-      //Contract.Requires(visitor != null);
       Contract.Ensures(Contract.Result<Absy>() != null);
       return visitor.VisitMapAssignLhs(this);
     }
@@ -1171,7 +1169,7 @@ namespace Microsoft.Boogie
 
     private List<Variable> _locals;
 
-    public /*readonly, except for the StandardVisitor*/ List<Variable> /*!*/ Locals
+    public /*readonly, except for the StandardVisitor*/ List<Variable> Locals
     {
       get
       {
@@ -1187,7 +1185,7 @@ namespace Microsoft.Boogie
 
     private List<Cmd> _cmds;
 
-    public /*readonly, except for the StandardVisitor*/ List<Cmd> /*!*/ Cmds
+    public /*readonly, except for the StandardVisitor*/ List<Cmd> Cmds
     {
       get
       {
@@ -1201,7 +1199,7 @@ namespace Microsoft.Boogie
       }
     }
 
-    public StateCmd(IToken tok, List<Variable> /*!*/ locals, List<Cmd> /*!*/ cmds)
+    public StateCmd(IToken tok, List<Variable> locals, List<Cmd> cmds)
       : base(tok)
     {
       Contract.Requires(locals != null);
@@ -1213,15 +1211,14 @@ namespace Microsoft.Boogie
 
     public override void Resolve(ResolutionContext rc)
     {
-      //Contract.Requires(rc != null);
       rc.PushVarContext();
-      foreach (Variable /*!*/ v in Locals)
+      foreach (Variable v in Locals)
       {
         Contract.Assert(v != null);
         rc.AddVariable(v);
       }
 
-      foreach (Cmd /*!*/ cmd in Cmds)
+      foreach (Cmd cmd in Cmds)
       {
         Contract.Assert(cmd != null);
         cmd.Resolve(rc);
@@ -1251,8 +1248,7 @@ namespace Microsoft.Boogie
 
     public override void Typecheck(TypecheckingContext tc)
     {
-      //Contract.Requires(tc != null);
-      foreach (Cmd /*!*/ cmd in Cmds)
+      foreach (Cmd cmd in Cmds)
       {
         Contract.Assert(cmd != null);
         cmd.Typecheck(tc);
@@ -1261,15 +1257,14 @@ namespace Microsoft.Boogie
 
     public override void Emit(TokenTextWriter stream, int level)
     {
-      //Contract.Requires(stream != null);
       stream.WriteLine(this, level, "{");
-      foreach (Variable /*!*/ v in Locals)
+      foreach (Variable v in Locals)
       {
         Contract.Assert(v != null);
         v.Emit(stream, level + 1);
       }
 
-      foreach (Cmd /*!*/ c in Cmds)
+      foreach (Cmd c in Cmds)
       {
         Contract.Assert(c != null);
         c.Emit(stream, level + 1);
@@ -1280,7 +1275,6 @@ namespace Microsoft.Boogie
 
     public override Absy StdDispatch(StandardVisitor visitor)
     {
-      //Contract.Requires(visitor != null);
       Contract.Ensures(Contract.Result<Absy>() != null);
       return visitor.VisitStateCmd(this);
     }
@@ -1330,7 +1324,7 @@ namespace Microsoft.Boogie
       }
     }
 
-    protected abstract Cmd /*!*/ ComputeDesugaring(PrintOptions options);
+    protected abstract Cmd ComputeDesugaring(PrintOptions options);
 
     public void ExtendDesugaring(CoreOptions options, IEnumerable<Cmd> before, IEnumerable<Cmd> beforePreconditionCheck,
       IEnumerable<Cmd> after)
@@ -1360,7 +1354,6 @@ namespace Microsoft.Boogie
 
     public override void Emit(TokenTextWriter stream, int level)
     {
-      //Contract.Requires(stream != null);
       if (stream.Options.PrintDesugarings && !stream.UseForComputingChecksums)
       {
         stream.WriteLine(this, level, "/*** desugaring:");
@@ -1427,7 +1420,7 @@ namespace Microsoft.Boogie
       Contract.Requires(likeThisOne != null);
       Contract.Requires(tempVars != null);
       Contract.Ensures(Contract.Result<Variable>() != null);
-      string /*!*/
+      string
         tempNamePrefix;
       switch (kind)
       {
@@ -1489,11 +1482,16 @@ namespace Microsoft.Boogie
 
     public override void Resolve(ResolutionContext rc)
     {
+      var errorCount = rc.ErrorCount;
       (this as ICarriesAttributes).ResolveAttributes(rc);
       foreach (CallCmd callCmd in CallCmds)
       {
         callCmd.Resolve(rc);
       }
+      if (errorCount > rc.ErrorCount)
+      {
+        return;
+      }
 
       HashSet<Variable> parallelCallLhss = new HashSet<Variable>();
       Dictionary<Variable, List<CallCmd>> inputVariables = new Dictionary<Variable, List<CallCmd>>();
@@ -1587,7 +1585,6 @@ namespace Microsoft.Boogie
 
     public override Absy StdDispatch(StandardVisitor visitor)
     {
-      //Contract.Requires(visitor != null);
       Contract.Ensures(Contract.Result<Absy>() != null);
       return visitor.VisitParCallCmd(this);
     }
@@ -1655,7 +1652,7 @@ namespace Microsoft.Boogie
   {
     public QKeyValue Attributes { get; set; }
 
-    public /*readonly--except in StandardVisitor*/ Expr /*!*/
+    public /*readonly--except in StandardVisitor*/ Expr
       Expr;
 
     [ContractInvariantMethod]
@@ -1665,7 +1662,7 @@ namespace Microsoft.Boogie
     }
 
     
-    public PredicateCmd(IToken /*!*/ tok, Expr /*!*/ expr)
+    public PredicateCmd(IToken tok, Expr expr)
       : base(tok)
     {
       Contract.Requires(tok != null);
@@ -1673,7 +1670,7 @@ namespace Microsoft.Boogie
       Expr = expr;
     }
 
-    public PredicateCmd(IToken /*!*/ tok, Expr /*!*/ expr, QKeyValue kv)
+    public PredicateCmd(IToken tok, Expr expr, QKeyValue kv)
       : base(tok)
     {
       Contract.Requires(tok != null);
@@ -1716,10 +1713,10 @@ namespace Microsoft.Boogie
 
   public class ListOfMiningStrategies : MiningStrategy
   {
-    private List<MiningStrategy> /*!*/
+    private List<MiningStrategy>
       _msList;
 
-    public List<MiningStrategy> /*!*/ msList
+    public List<MiningStrategy> msList
     {
       get
       {
@@ -1748,10 +1745,10 @@ namespace Microsoft.Boogie
 
   public class EEDTemplate : MiningStrategy
   {
-    private string /*!*/
+    private string
       _reason;
 
-    public string /*!*/ reason
+    public string reason
     {
       get
       {
@@ -1765,7 +1762,7 @@ namespace Microsoft.Boogie
       }
     }
 
-    private List<Expr /*!*/> /*!*/
+    private List<Expr>
       exprList;
 
     public IEnumerable<Expr> Expressions
@@ -1790,7 +1787,7 @@ namespace Microsoft.Boogie
       Contract.Invariant(Cce.NonNullElements(this.exprList));
     }
 
-    public EEDTemplate(string reason, List<Expr /*!*/> /*!*/ exprList)
+    public EEDTemplate(string reason, List<Expr> exprList)
     {
       Contract.Requires(reason != null);
       Contract.Requires(Cce.NonNullElements(exprList));
@@ -1912,7 +1909,7 @@ namespace Microsoft.Boogie
       {
         QuantifierExpr qe = (QuantifierExpr) expr;
         List<Variable> vs = qe.Dummies;
-        foreach (Variable /*!*/ x in vs)
+        foreach (Variable x in vs)
         {
           Contract.Assert(x != null);
           string name = x.Name;
@@ -1944,7 +1941,7 @@ namespace Microsoft.Boogie
   {
     public readonly AssertCmd originalAssert;
 
-    public LoopInitAssertCmd(IToken /*!*/ tok, Expr /*!*/ expr, AssertCmd original)
+    public LoopInitAssertCmd(IToken tok, Expr expr, AssertCmd original)
       : base(tok, expr, new InvariantEstablishedDescription())
     {
       this.originalAssert = original;
@@ -1958,7 +1955,7 @@ namespace Microsoft.Boogie
   {
     public readonly AssertCmd originalAssert;
 
-    public LoopInvMaintainedAssertCmd(IToken /*!*/ tok, Expr /*!*/ expr, AssertCmd original)
+    public LoopInvMaintainedAssertCmd(IToken tok, Expr expr, AssertCmd original)
       : base(tok, expr, new InvariantMaintainedDescription())
     {
       this.originalAssert = original;
@@ -1972,9 +1969,9 @@ namespace Microsoft.Boogie
   /// </summary>
   public class AssertRequiresCmd : AssertCmd
   {
-    public CallCmd /*!*/ Call;
+    public CallCmd Call;
 
-    public Requires /*!*/ Requires;
+    public Requires Requires;
 
     [ContractInvariantMethod]
     void ObjectInvariant()
@@ -1984,7 +1981,7 @@ namespace Microsoft.Boogie
     }
 
 
-    public AssertRequiresCmd(CallCmd /*!*/ call, Requires /*!*/ requires)
+    public AssertRequiresCmd(CallCmd call, Requires requires)
       : base(call.tok, requires.Condition, requires.Description)
     {
       Contract.Requires(call != null);
@@ -1995,7 +1992,6 @@ namespace Microsoft.Boogie
 
     public override Absy StdDispatch(StandardVisitor visitor)
     {
-      //Contract.Requires(visitor != null);
       Contract.Ensures(Contract.Result<Absy>() != null);
       return visitor.VisitAssertRequiresCmd(this);
     }
@@ -2007,7 +2003,7 @@ namespace Microsoft.Boogie
   /// </summary>
   public class AssertEnsuresCmd : AssertCmd
   {
-    public Ensures /*!*/
+    public Ensures
       Ensures;
 
     [ContractInvariantMethod]
@@ -2016,7 +2012,7 @@ namespace Microsoft.Boogie
       Contract.Invariant(Ensures != null);
     }
 
-    public AssertEnsuresCmd(Ensures /*!*/ ens)
+    public AssertEnsuresCmd(Ensures ens)
       : base(ens.tok, ens.Condition, ens.Description)
     {
       Contract.Requires(ens != null);
@@ -2025,7 +2021,6 @@ namespace Microsoft.Boogie
 
     public override Absy StdDispatch(StandardVisitor visitor)
     {
-      //Contract.Requires(visitor != null);
       Contract.Ensures(Contract.Result<Absy>() != null);
       return visitor.VisitAssertEnsuresCmd(this);
     }
@@ -2033,14 +2028,14 @@ namespace Microsoft.Boogie
 
   public class AssumeCmd : PredicateCmd
   {
-    public AssumeCmd(IToken /*!*/ tok, Expr /*!*/ expr)
+    public AssumeCmd(IToken tok, Expr expr)
       : base(tok, expr)
     {
       Contract.Requires(tok != null);
       Contract.Requires(expr != null);
     }
 
-    public AssumeCmd(IToken /*!*/ tok, Expr /*!*/ expr, QKeyValue kv)
+    public AssumeCmd(IToken tok, Expr expr, QKeyValue kv)
       : base(tok, expr, kv)
     {
       Contract.Requires(tok != null);
@@ -2049,7 +2044,6 @@ namespace Microsoft.Boogie
 
     public override void Emit(TokenTextWriter stream, int level)
     {
-      //Contract.Requires(stream != null);
       stream.Write(this, level, "assume ");
       EmitAttributes(stream, Attributes);
       this.Expr.Emit(stream);
@@ -2085,7 +2079,7 @@ namespace Microsoft.Boogie
 
   public class ReturnExprCmd : ReturnCmd
   {
-    public Expr /*!*/ Expr;
+    public Expr Expr;
 
     [ContractInvariantMethod]
     void ObjectInvariant()
@@ -2093,7 +2087,7 @@ namespace Microsoft.Boogie
       Contract.Invariant(Expr != null);
     }
 
-    public ReturnExprCmd(IToken /*!*/ tok, Expr /*!*/ expr)
+    public ReturnExprCmd(IToken tok, Expr expr)
       : base(tok)
     {
       Contract.Requires(tok != null);
@@ -2103,7 +2097,6 @@ namespace Microsoft.Boogie
 
     public override void Emit(TokenTextWriter stream, int level)
     {
-      //Contract.Requires(stream != null);
       stream.Write(this, level, "return ");
       this.Expr.Emit(stream);
       stream.WriteLine(";");
@@ -2111,7 +2104,6 @@ namespace Microsoft.Boogie
 
     public override void Typecheck(TypecheckingContext tc)
     {
-      //Contract.Requires(tc != null);
       Expr.Typecheck(tc);
       Contract.Assert(Expr.Type != null); // follows from Expr.Typecheck postcondition
       if (!Expr.Type.Unify(Type.Bool))
@@ -2122,13 +2114,11 @@ namespace Microsoft.Boogie
 
     public override void Resolve(ResolutionContext rc)
     {
-      //Contract.Requires(rc != null);
       Expr.Resolve(rc);
     }
 
     public override Absy StdDispatch(StandardVisitor visitor)
     {
-      //Contract.Requires(visitor != null);
       Contract.Ensures(Contract.Result<Absy>() != null);
       return visitor.VisitReturnExprCmd(this);
     }
@@ -2136,9 +2126,9 @@ namespace Microsoft.Boogie
 
   public class HavocCmd : Cmd
   {
-    private List<IdentifierExpr> /*!*/ _vars;
+    private List<IdentifierExpr> _vars;
 
-    public List<IdentifierExpr> /*!*/ Vars
+    public List<IdentifierExpr> Vars
     {
       get
       {
@@ -2158,7 +2148,7 @@ namespace Microsoft.Boogie
       Contract.Invariant(this._vars != null);
     }
 
-    public HavocCmd(IToken /*!*/ tok, List<IdentifierExpr> /*!*/ vars)
+    public HavocCmd(IToken tok, List<IdentifierExpr> vars)
       : base(tok)
     {
       Contract.Requires(tok != null);
@@ -2168,7 +2158,6 @@ namespace Microsoft.Boogie
 
     public override void Emit(TokenTextWriter stream, int level)
     {
-      //Contract.Requires(stream != null);
       stream.Write(this, level, "havoc ");
       Vars.Emit(stream, true);
       stream.WriteLine(";");
@@ -2176,8 +2165,7 @@ namespace Microsoft.Boogie
 
     public override void Resolve(ResolutionContext rc)
     {
-      //Contract.Requires(rc != null);
-      foreach (IdentifierExpr /*!*/ ide in Vars)
+      foreach (IdentifierExpr ide in Vars)
       {
         Contract.Assert(ide != null);
         ide.Resolve(rc);
@@ -2185,7 +2173,7 @@ namespace Microsoft.Boogie
     }
 
     public override void AddAssignedIdentifiers(List<IdentifierExpr> vars) {
-      foreach (IdentifierExpr /*!*/ e in this.Vars)
+      foreach (IdentifierExpr e in this.Vars)
       {
         Contract.Assert(e != null);
         vars.Add(e);
@@ -2194,7 +2182,6 @@ namespace Microsoft.Boogie
 
     public override void Typecheck(TypecheckingContext tc)
     {
-      //Contract.Requires(tc != null);
       foreach (IdentifierExpr ie in Vars)
       {
         ie.Typecheck(tc);
@@ -2205,7 +2192,6 @@ namespace Microsoft.Boogie
 
     public override Absy StdDispatch(StandardVisitor visitor)
     {
-      //Contract.Requires(visitor != null);
       Contract.Ensures(Contract.Result<Absy>() != null);
       return visitor.VisitHavocCmd(this);
     }
