@@ -8,16 +8,16 @@ namespace Microsoft.Boogie;
 
 public class CallCmd : CallCommonality
 {
-  public string /*!*/ callee { get; set; }
+  public string callee { get; set; }
   public Procedure Proc;
   public LocalVariable AssignedAssumptionVariable;
 
   // Element of the following lists can be null, which means that
   // the call happens with * as these parameters
-  public List<Expr> /*!*/
+  public List<Expr>
     Ins;
 
-  public List<IdentifierExpr> /*!*/
+  public List<IdentifierExpr>
     Outs;
 
   [ContractInvariantMethod]
@@ -532,7 +532,7 @@ public class CallCmd : CallCommonality
     }
 
     Contract.Assume(this.Proc != null);
-    foreach (IdentifierExpr /*!*/ e in this.Proc.Modifies)
+    foreach (IdentifierExpr e in this.Proc.Modifies)
     {
       Contract.Assert(e != null);
       vars.Add(e);
@@ -626,13 +626,13 @@ public class CallCmd : CallCommonality
 
     this.CheckAssignments(tc);
 
-    List<Type> /*!*/
+    List<Type>
       formalInTypes = new List<Type>();
-    List<Type> /*!*/
+    List<Type>
       formalOutTypes = new List<Type>();
-    List<Expr> /*!*/
+    List<Expr>
       actualIns = new List<Expr>();
-    List<IdentifierExpr> /*!*/
+    List<IdentifierExpr>
       actualOuts = new List<IdentifierExpr>();
     for (int i = 0; i < Ins.Count; ++i)
     {
@@ -702,13 +702,13 @@ public class CallCmd : CallCommonality
     return formalLayerRange;
   }
 
-  private IDictionary<TypeVariable /*!*/, Type /*!*/> /*!*/ TypeParamSubstitution()
+  private IDictionary<TypeVariable, Type> TypeParamSubstitution()
   {
     Contract.Ensures(Cce.NonNullDictionaryAndValues(Contract.Result<IDictionary<TypeVariable, Type>>()));
     Contract.Assume(TypeParameters != null);
-    IDictionary<TypeVariable /*!*/, Type /*!*/> /*!*/
-      res = new Dictionary<TypeVariable /*!*/, Type /*!*/>();
-    foreach (TypeVariable /*!*/ v in TypeParameters.FormalTypeParams)
+    IDictionary<TypeVariable, Type>
+      res = new Dictionary<TypeVariable, Type>();
+    foreach (TypeVariable v in TypeParameters.FormalTypeParams)
     {
       Contract.Assert(v != null);
       res.Add(v, TypeParameters[v]);
@@ -726,7 +726,7 @@ public class CallCmd : CallCommonality
     Dictionary<Variable, Expr> substMap = new Dictionary<Variable, Expr>();
     Dictionary<Variable, Expr> substMapOld = new Dictionary<Variable, Expr>();
     Dictionary<Variable, Expr> substMapBound = new Dictionary<Variable, Expr>();
-    List<Variable> /*!*/
+    List<Variable>
       tempVars = new List<Variable>();
     string callId = (this as ICarriesAttributes).FindStringAttribute("id");
 
@@ -749,17 +749,17 @@ public class CallCmd : CallCommonality
 
     #region Create cins; each one is an incarnation of the corresponding in parameter
 
-    List<Variable> /*!*/
+    List<Variable>
       cins = new List<Variable>();
     List<Variable> wildcardVars = new List<Variable>();
     Contract.Assume(this.Proc != null);
     for (int i = 0; i < this.Proc.InParams.Count; ++i)
     {
-      Variable /*!*/
+      Variable
         param = Cce.NonNull(this.Proc.InParams[i]);
       bool isWildcard = this.Ins[i] == null;
 
-      Type /*!*/
+      Type
         actualType;
       if (isWildcard)
       {
@@ -796,7 +796,7 @@ public class CallCmd : CallCommonality
 
     for (int i = 0, n = this.Ins.Count; i < n; i++)
     {
-      IdentifierExpr /*!*/
+      IdentifierExpr
         cin_exp = new IdentifierExpr(Cce.NonNull(cins[i]).tok, Cce.NonNull(cins[i]));
       Contract.Assert(cin_exp != null);
       if (this.Ins[i] != null)
@@ -806,7 +806,7 @@ public class CallCmd : CallCommonality
       }
       else
       {
-        List<IdentifierExpr> /*!*/
+        List<IdentifierExpr>
           ies = new List<IdentifierExpr>();
         ies.Add(cin_exp);
         HavocCmd havoc = new HavocCmd(Token.NoToken, ies);
@@ -823,7 +823,7 @@ public class CallCmd : CallCommonality
     Expr preConjunction = null;
     for (int i = 0; i < this.Proc.Requires.Count; i++)
     {
-      Requires /*!*/
+      Requires
         req = Cce.NonNull(this.Proc.Requires[i]);
       if (!req.Free && !IsFree)
       {
@@ -841,10 +841,10 @@ public class CallCmd : CallCommonality
         }
         else
         {
-          Requires /*!*/
-            reqCopy = (Requires /*!*/) Cce.NonNull(req.Clone());
+          Requires
+            reqCopy = (Requires) Cce.NonNull(req.Clone());
           reqCopy.Condition = Substituter.Apply(s, req.Condition);
-          AssertCmd /*!*/
+          AssertCmd
             a = new AssertRequiresCmd(this, reqCopy);
           Contract.Assert(a != null);
 
@@ -870,7 +870,7 @@ public class CallCmd : CallCommonality
                || options.StratifiedInlining > 0)
       {
         // inject free requires as assume statements at the call site
-        AssumeCmd /*!*/
+        AssumeCmd
           a = new AssumeCmd(req.tok, Substituter.Apply(s, req.Condition));
         Contract.Assert(a != null);
         // These probably won't have IDs, but copy if they do.
@@ -890,10 +890,10 @@ public class CallCmd : CallCommonality
         preConjunction = Expr.True;
       }
 
-      Expr /*!*/
+      Expr
         expr = new ExistsExpr(tok, wildcardVars, preConjunction);
       Contract.Assert(expr != null);
-      AssertCmd /*!*/
+      AssertCmd
         a = new AssertCmd(tok, expr);
       Contract.Assert(a != null);
       if (Attributes != null)
@@ -917,14 +917,14 @@ public class CallCmd : CallCommonality
       s = Substituter.SubstitutionFromDictionary(substMap);
       for (int i = 0; i < this.Proc.Requires.Count; i++)
       {
-        Requires /*!*/
+        Requires
           req = Cce.NonNull(this.Proc.Requires[i]);
         if (!req.Free)
         {
-          Requires /*!*/
-            reqCopy = (Requires /*!*/) Cce.NonNull(req.Clone());
+          Requires
+            reqCopy = (Requires) Cce.NonNull(req.Clone());
           reqCopy.Condition = Substituter.Apply(s, req.Condition);
-          AssumeCmd /*!*/
+          AssumeCmd
             a = new AssumeCmd(tok, reqCopy.Condition);
           Contract.Assert(a != null);
           newBlockBody.Add(a);
@@ -938,7 +938,7 @@ public class CallCmd : CallCommonality
 
     List<IdentifierExpr> havocVarExprs = new List<IdentifierExpr>();
 
-    foreach (IdentifierExpr /*!*/ f in this.Proc.Modifies)
+    foreach (IdentifierExpr f in this.Proc.Modifies)
     {
       Contract.Assert(f != null);
       Contract.Assume(f.Decl != null);
@@ -960,15 +960,15 @@ public class CallCmd : CallCommonality
 
     #region Create couts
 
-    List<Variable> /*!*/
+    List<Variable>
       couts = new List<Variable>();
     for (int i = 0; i < this.Proc.OutParams.Count; ++i)
     {
-      Variable /*!*/
+      Variable
         param = Cce.NonNull(this.Proc.OutParams[i]);
       bool isWildcard = this.Outs[i] == null;
 
-      Type /*!*/
+      Type
         actualType;
       if (isWildcard)
       {
@@ -994,13 +994,13 @@ public class CallCmd : CallCommonality
     }
 
     // add the where clauses, now that we have the entire substitution map
-    foreach (Variable /*!*/ param in this.Proc.OutParams)
+    foreach (Variable param in this.Proc.OutParams)
     {
       Contract.Assert(param != null);
       Expr w = param.TypedIdent.WhereExpr;
       if (w != null)
       {
-        IdentifierExpr ie = (IdentifierExpr /*!*/) Cce.NonNull(substMap[param]);
+        IdentifierExpr ie = (IdentifierExpr) Cce.NonNull(substMap[param]);
         Contract.Assert(ie.Decl != null);
         ie.Decl.TypedIdent.WhereExpr = Substituter.Apply(Substituter.SubstitutionFromDictionary(substMap), w);
       }
@@ -1020,7 +1020,7 @@ public class CallCmd : CallCommonality
 
     calleeSubstitution = Substituter.SubstitutionFromDictionary(substMap, true, Proc);
     calleeSubstitutionOld = Substituter.SubstitutionFromDictionary(substMapOld, true, Proc);
-    foreach (Ensures /*!*/ e in this.Proc.Ensures)
+    foreach (Ensures e in this.Proc.Ensures)
     {
       Contract.Assert(e != null);
       Expr copy = Substituter.ApplyReplacingOldExprs(calleeSubstitution, calleeSubstitutionOld, e.Condition);
@@ -1057,9 +1057,9 @@ public class CallCmd : CallCommonality
     {
       if (this.Outs[i] != null)
       {
-        Variable /*!*/
+        Variable
           param_i = Cce.NonNull(this.Proc.OutParams[i]);
-        Expr /*!*/
+        Expr
           cout_exp = new IdentifierExpr(Cce.NonNull(couts[i]).tok, Cce.NonNull(couts[i]));
         Contract.Assert(cout_exp != null);
         AssignCmd assign = Cmd.SimpleAssign(param_i.tok, Cce.NonNull(this.Outs[i]), cout_exp);
@@ -1152,7 +1152,6 @@ public class CallCmd : CallCommonality
 
   public override Absy StdDispatch(StandardVisitor visitor)
   {
-    //Contract.Requires(visitor != null);
     Contract.Ensures(Contract.Result<Absy>() != null);
     return visitor.VisitCallCmd(this);
   }
