@@ -46,7 +46,7 @@ namespace Microsoft.Boogie.VCExprAST
   public class Boogie2VCExprTranslator : ReadOnlyVisitor, ICloneable
   {
     // Stack on which the various Visit-methods put the result of the translation
-    private readonly Stack<VCExpr /*!*/> /*!*/
+    private readonly Stack<VCExpr>
       SubExpressions = new Stack<VCExpr>();
 
     [ContractInvariantMethod]
@@ -77,12 +77,12 @@ namespace Microsoft.Boogie.VCExprAST
       return Pop();
     }
 
-    public List<VCExpr /*!*/> /*!*/ Translate(IList<Expr> exprs)
+    public List<VCExpr> Translate(IList<Expr> exprs)
     {
       Contract.Requires(exprs != null);
       Contract.Ensures(Cce.NonNullElements(Contract.Result<List<VCExpr>>()));
-      List<VCExpr /*!*/> /*!*/
-        res = new List<VCExpr /*!*/>();
+      List<VCExpr>
+        res = new List<VCExpr>();
       foreach (Expr e in exprs)
       {
         res.Add(Translate(Cce.NonNull(e)));
@@ -93,7 +93,7 @@ namespace Microsoft.Boogie.VCExprAST
 
     ///////////////////////////////////////////////////////////////////////////////
 
-    internal readonly VCExpressionGenerator /*!*/
+    internal readonly VCExpressionGenerator
       Gen;
 
     public Boogie2VCExprTranslator(VCExpressionGenerator gen,
@@ -147,7 +147,7 @@ namespace Microsoft.Boogie.VCExprAST
 
     private class VariableMapping<VarKind> : ICloneable
     {
-      private readonly List<Dictionary<VarKind /*!*/, VCExprVar /*!*/> /*!*/> /*!*/
+      private readonly List<Dictionary<VarKind, VCExprVar>>
         Mapping;
 
       [ContractInvariantMethod]
@@ -159,23 +159,23 @@ namespace Microsoft.Boogie.VCExprAST
 
       public VariableMapping()
       {
-        List<Dictionary<VarKind /*!*/, VCExprVar /*!*/> /*!*/> /*!*/
+        List<Dictionary<VarKind, VCExprVar>>
           mapping =
-            new List<Dictionary<VarKind /*!*/, VCExprVar /*!*/> /*!*/>();
-        mapping.Add(new Dictionary<VarKind /*!*/, VCExprVar /*!*/>());
+            new List<Dictionary<VarKind, VCExprVar>>();
+        mapping.Add(new Dictionary<VarKind, VCExprVar>());
         this.Mapping = mapping;
       }
 
       private VariableMapping(VariableMapping<VarKind> vm)
       {
         Contract.Requires(vm != null);
-        List<Dictionary<VarKind /*!*/, VCExprVar /*!*/> /*!*/> /*!*/
+        List<Dictionary<VarKind, VCExprVar>>
           mapping =
-            new List<Dictionary<VarKind /*!*/, VCExprVar /*!*/> /*!*/>();
-        foreach (Dictionary<VarKind /*!*/, VCExprVar /*!*/> /*!*/ d in vm.Mapping)
+            new List<Dictionary<VarKind, VCExprVar>>();
+        foreach (Dictionary<VarKind, VCExprVar> d in vm.Mapping)
         {
           Contract.Assert(Cce.NonNullDictionaryAndValues(d));
-          mapping.Add(new Dictionary<VarKind /*!*/, VCExprVar /*!*/>(d));
+          mapping.Add(new Dictionary<VarKind, VCExprVar>(d));
         }
 
         this.Mapping = mapping;
@@ -189,7 +189,7 @@ namespace Microsoft.Boogie.VCExprAST
 
       public void PushScope()
       {
-        Mapping.Add(new Dictionary<VarKind /*!*/, VCExprVar /*!*/>());
+        Mapping.Add(new Dictionary<VarKind, VCExprVar>());
       }
 
       public void PopScope()
@@ -198,7 +198,7 @@ namespace Microsoft.Boogie.VCExprAST
         Mapping.RemoveAt(Mapping.Count - 1);
       }
 
-      public void Bind(VarKind boogieVar, VCExprVar /*!*/ vcExprVar)
+      public void Bind(VarKind boogieVar, VCExprVar vcExprVar)
       {
         Contract.Requires(vcExprVar != null);
         Contract.Requires(boogieVar != null);
@@ -233,7 +233,7 @@ namespace Microsoft.Boogie.VCExprAST
       private VCExprVar LookupHelp(VarKind boogieVar)
       {
         Contract.Requires(boogieVar != null);
-        foreach (Dictionary<VarKind /*!*/, VCExprVar /*!*/> /*!*/ d in Mapping)
+        foreach (Dictionary<VarKind, VCExprVar> d in Mapping)
         {
           //Contract.Assert(cce.NonNullElements(d));
           if (d.TryGetValue(boogieVar, out var res))
@@ -249,14 +249,14 @@ namespace Microsoft.Boogie.VCExprAST
 
     //////////////////////////////////////////////////////////////////////////////////
 
-    private readonly VariableMapping<Variable> /*!*/
+    private readonly VariableMapping<Variable>
       UnboundVariables;
 
-    private readonly VariableMapping<BoundVariable> /*!*/
+    private readonly VariableMapping<BoundVariable>
       BoundVariables;
 
     // used when translating the bodies of function expansions
-    private readonly VariableMapping<Formal> /*!*/
+    private readonly VariableMapping<Formal>
       Formals;
 
     [ContractInvariantMethod]
@@ -294,14 +294,14 @@ namespace Microsoft.Boogie.VCExprAST
       Contract.Ensures(Contract.Result<VCExprVar>() != null);
       if (boogieVar is BoundVariable)
       {
-        VCExprVar /*!*/
+        VCExprVar
           newVar = Gen.Variable(boogieVar.Name, boogieVar.TypedIdent.Type);
         BoundVariables.Bind((BoundVariable) boogieVar, newVar);
         return newVar;
       }
       else if (boogieVar is Formal)
       {
-        VCExprVar /*!*/
+        VCExprVar
           newVar = Gen.Variable(boogieVar.Name, boogieVar.TypedIdent.Type);
         Formals.Bind((Formal) boogieVar, newVar);
         return newVar;
@@ -377,7 +377,7 @@ namespace Microsoft.Boogie.VCExprAST
 
     ///////////////////////////////////////////////////////////////////////////////////
 
-    internal readonly VCGenerationOptions /*!*/
+    internal readonly VCGenerationOptions
       GenerationOptions;
 
     [ContractInvariantMethod]
@@ -390,7 +390,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Expr VisitLiteralExpr(LiteralExpr node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Expr>() != null);
       Push(TranslateLiteralExpr(node));
       return node;
@@ -448,7 +447,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Expr VisitIdentifierExpr(IdentifierExpr node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Expr>() != null);
       Contract.Assume(node.Decl != null); // the expression has to be resolved
       Push(LookupVariable(node.Decl));
@@ -463,7 +461,6 @@ namespace Microsoft.Boogie.VCExprAST
     // before transforming it into a VCExpr.
     public override Expr VisitOldExpr(OldExpr node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Expr>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -473,7 +470,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Expr VisitNAryExpr(NAryExpr node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Expr>() != null);
       Push(TranslateNAryExpr(node));
       return node;
@@ -510,8 +506,8 @@ namespace Microsoft.Boogie.VCExprAST
       }
 
       int n = node.Args.Count;
-      List<VCExpr /*!*/> /*!*/
-        vcs = new List<VCExpr /*!*/>(n);
+      List<VCExpr>
+        vcs = new List<VCExpr>(n);
 
       for (int i = 0; i < n; i++)
       {
@@ -539,8 +535,8 @@ namespace Microsoft.Boogie.VCExprAST
     }
 
 
-    private static List<Type /*!*/> /*!*/
-      EMPTY_TYPE_LIST = new List<Type /*!*/>();
+    private static List<Type>
+      EMPTY_TYPE_LIST = new List<Type>();
 
     [ContractInvariantMethod]
     void ObjectInvirant()
@@ -549,7 +545,7 @@ namespace Microsoft.Boogie.VCExprAST
     }
 
 
-    private List<Type /*!*/> /*!*/ ToList(TypeParamInstantiation insts)
+    private List<Type> ToList(TypeParamInstantiation insts)
     {
       Contract.Requires(insts != null);
       Contract.Ensures(Cce.NonNullElements(Contract.Result<List<Type>>()));
@@ -558,9 +554,9 @@ namespace Microsoft.Boogie.VCExprAST
         return EMPTY_TYPE_LIST;
       }
 
-      List<Type /*!*/> /*!*/
-        typeArgs = new List<Type /*!*/>();
-      foreach (TypeVariable /*!*/ var in insts.FormalTypeParams)
+      List<Type>
+        typeArgs = new List<Type>();
+      foreach (TypeVariable var in insts.FormalTypeParams)
       {
         Contract.Assert(var != null);
         typeArgs.Add(insts[var]);
@@ -573,7 +569,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override QuantifierExpr VisitQuantifierExpr(QuantifierExpr node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<QuantifierExpr>() != null);
       Push(TranslateQuantifierExpr(node));
       return node;
@@ -581,7 +576,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Expr VisitExistsExpr(ExistsExpr node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Expr>() != null);
       node = (ExistsExpr) this.VisitQuantifierExpr(node);
       return node;
@@ -589,7 +583,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Expr VisitForallExpr(ForallExpr node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Expr>() != null);
       node = (ForallExpr) this.VisitQuantifierExpr(node);
       return node;
@@ -599,9 +592,9 @@ namespace Microsoft.Boogie.VCExprAST
     {
       Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<VCExpr>() != null);
-      List<TypeVariable /*!*/> /*!*/
-        typeParams = new List<TypeVariable /*!*/>();
-      foreach (TypeVariable /*!*/ v in node.TypeParameters)
+      List<TypeVariable>
+        typeParams = new List<TypeVariable>();
+      foreach (TypeVariable v in node.TypeParameters)
       {
         Contract.Assert(v != null);
         typeParams.Add(v);
@@ -609,20 +602,20 @@ namespace Microsoft.Boogie.VCExprAST
 
       PushBoundVariableScope();
 
-      List<VCExprVar /*!*/> /*!*/
-        boundVars = new List<VCExprVar /*!*/>();
-      foreach (Variable /*!*/ v in node.Dummies)
+      List<VCExprVar>
+        boundVars = new List<VCExprVar>();
+      foreach (Variable v in node.Dummies)
       {
         boundVars.Add(BindVariable(v));
       }
 
       try
       {
-        List<VCTrigger /*!*/> /*!*/
+        List<VCTrigger>
           triggers = TranslateTriggers(node.Triggers);
-        VCExpr /*!*/
+        VCExpr
           body = Translate(node.Body);
-        VCQuantifierInfo /*!*/
+        VCQuantifierInfo
           info = GenerateQuantifierInfo(node, boundVars);
 
         Quantifier quan;
@@ -648,11 +641,11 @@ namespace Microsoft.Boogie.VCExprAST
       }
     }
 
-    private List<VCTrigger /*!*/> /*!*/ TranslateTriggers(Trigger node)
+    private List<VCTrigger> TranslateTriggers(Trigger node)
     {
       Contract.Ensures(Cce.NonNullElements(Contract.Result<List<VCTrigger>>()));
-      List<VCTrigger /*!*/> /*!*/
-        res = new List<VCTrigger /*!*/>();
+      List<VCTrigger>
+        res = new List<VCTrigger>();
       Trigger curTrigger = node;
       while (curTrigger != null)
       {
@@ -752,7 +745,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Expr VisitBvExtractExpr(BvExtractExpr node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Expr>() != null);
       Push(TranslateBvExtractExpr(node));
       return node;
@@ -763,7 +755,7 @@ namespace Microsoft.Boogie.VCExprAST
       Contract.Requires(node != null);
       Contract.Requires((node.Start <= node.End));
       Contract.Ensures(Contract.Result<VCExpr>() != null);
-      VCExpr /*!*/
+      VCExpr
         bv = Translate(node.Bitvector);
       return Gen.BvExtract(bv, Cce.NonNull(node.Bitvector.Type).BvBits, node.Start, node.End);
     }
@@ -772,7 +764,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Expr VisitBvConcatExpr(BvConcatExpr node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Expr>() != null);
       Push(TranslateBvConcatExpr(node));
       return node;
@@ -782,9 +773,9 @@ namespace Microsoft.Boogie.VCExprAST
     {
       Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<VCExpr>() != null);
-      VCExpr /*!*/
+      VCExpr
         bv0 = Translate(node.E0);
-      VCExpr /*!*/
+      VCExpr
         bv1 = Translate(node.E1);
       return Gen.BvConcat(bv0, bv1);
     }
@@ -794,7 +785,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Cmd VisitAssertCmd(AssertCmd node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Cmd>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -816,7 +806,6 @@ namespace Microsoft.Boogie.VCExprAST
     
     public override Cmd VisitAssumeCmd(AssumeCmd node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Cmd>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -824,7 +813,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override AtomicRE VisitAtomicRE(AtomicRE node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<AtomicRE>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -832,7 +820,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Axiom VisitAxiom(Axiom node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Axiom>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -840,7 +827,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Type VisitBasicType(BasicType node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Type>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -848,7 +834,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Type VisitBvType(BvType node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Type>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -856,7 +841,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Block VisitBlock(Block node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Block>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -871,7 +855,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Expr VisitCodeExpr(CodeExpr codeExpr)
     {
-      //Contract.Requires(codeExpr != null);
       Contract.Ensures(Contract.Result<Expr>() != null);
       Contract.Assume(codeExprConverter != null);
       
@@ -883,15 +866,13 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override List<Block> VisitBlockSeq(List<Block> blockSeq)
     {
-      //Contract.Requires(blockSeq != null);
       Contract.Ensures(Contract.Result<List<Block>>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
     }
 
-    public override IList<Block> /*!*/ VisitBlockList(IList<Block> blocks /*!*/ /*!*/)
+    public override IList<Block> VisitBlockList(IList<Block> blocks)
     {
-      //Contract.Requires(cce.NonNullElements(blocks));
       Contract.Ensures(Cce.NonNullElements(Contract.Result<List<Block>>()));
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -899,7 +880,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override BoundVariable VisitBoundVariable(BoundVariable node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<BoundVariable>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -907,7 +887,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Cmd VisitCallCmd(CallCmd node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Cmd>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -915,7 +894,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Cmd VisitParCallCmd(ParCallCmd node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Cmd>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -923,7 +901,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override List<Cmd> VisitCmdSeq(List<Cmd> cmdSeq)
     {
-      //Contract.Requires(cmdSeq != null);
       Contract.Ensures(Contract.Result<List<Cmd>>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -931,7 +908,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Choice VisitChoice(Choice node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Choice>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -939,7 +915,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Cmd VisitCommentCmd(CommentCmd node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Cmd>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -947,7 +922,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Constant VisitConstant(Constant node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Constant>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -955,7 +929,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override CtorType VisitCtorType(CtorType node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<CtorType>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -963,15 +936,13 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Declaration VisitDeclaration(Declaration node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Declaration>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
     }
 
-    public override List<Declaration /*!*/> /*!*/ VisitDeclarationList(List<Declaration /*!*/> /*!*/ declarationList)
+    public override List<Declaration> VisitDeclarationList(List<Declaration> declarationList)
     {
-      //Contract.Requires(cce.NonNullElements(declarationList));
       Contract.Ensures(Cce.NonNullElements(Contract.Result<List<Declaration>>()));
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -979,7 +950,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override DeclWithFormals VisitDeclWithFormals(DeclWithFormals node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<DeclWithFormals>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -987,7 +957,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Requires VisitRequires(Requires @requires)
     {
-      //Contract.Requires(@requires != null);
       Contract.Ensures(Contract.Result<Requires>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -995,7 +964,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override List<Requires> VisitRequiresSeq(List<Requires> requiresSeq)
     {
-      //Contract.Requires(requiresSeq != null);
       Contract.Ensures(Contract.Result<List<Requires>>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1003,7 +971,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Ensures VisitEnsures(Ensures @ensures)
     {
-      //Contract.Requires(@ensures != null);
       Contract.Ensures(Contract.Result<Ensures>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1011,7 +978,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override List<Ensures> VisitEnsuresSeq(List<Ensures> ensuresSeq)
     {
-      //Contract.Requires(ensuresSeq != null);
       Contract.Ensures(Contract.Result<List<Ensures>>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1019,7 +985,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Formal VisitFormal(Formal node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Formal>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1027,7 +992,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Function VisitFunction(Function node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Function>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1035,7 +999,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override GlobalVariable VisitGlobalVariable(GlobalVariable node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<GlobalVariable>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1043,7 +1006,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override GotoCmd VisitGotoCmd(GotoCmd node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<GotoCmd>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1051,7 +1013,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Cmd VisitHavocCmd(HavocCmd node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Cmd>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1059,7 +1020,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Implementation VisitImplementation(Implementation node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Implementation>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1067,7 +1027,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override LocalVariable VisitLocalVariable(LocalVariable node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<LocalVariable>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1075,7 +1034,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override AssignLhs VisitMapAssignLhs(MapAssignLhs node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<AssignLhs>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1083,7 +1041,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Type VisitMapType(MapType node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<MapType>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1091,7 +1048,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Procedure VisitProcedure(Procedure node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Procedure>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1099,7 +1055,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Program VisitProgram(Program node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Program>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1107,7 +1062,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Cmd VisitRE(RE node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Cmd>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1115,7 +1069,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override List<RE> VisitRESeq(List<RE> reSeq)
     {
-      //Contract.Requires(reSeq != null);
       Contract.Ensures(Contract.Result<List<RE>>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1123,7 +1076,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override ReturnCmd VisitReturnCmd(ReturnCmd node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<ReturnCmd>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1131,7 +1083,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override ReturnExprCmd VisitReturnExprCmd(ReturnExprCmd node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<ReturnExprCmd>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1139,7 +1090,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Sequential VisitSequential(Sequential node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Sequential>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1147,7 +1097,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override AssignLhs VisitSimpleAssignLhs(SimpleAssignLhs node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<AssignLhs>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1155,7 +1104,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Cmd VisitStateCmd(StateCmd node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Cmd>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1163,7 +1111,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override TransferCmd VisitTransferCmd(TransferCmd node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<TransferCmd>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1171,7 +1118,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Trigger VisitTrigger(Trigger node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Trigger>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1179,7 +1125,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Type VisitType(Type node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Type>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1187,7 +1132,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override TypedIdent VisitTypedIdent(TypedIdent node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<TypedIdent>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1195,7 +1139,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Type VisitTypeSynonymAnnotation(TypeSynonymAnnotation node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Type>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1203,7 +1146,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Type VisitTypeVariable(TypeVariable node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Type>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1211,7 +1153,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Variable VisitVariable(Variable node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Variable>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1219,7 +1160,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override List<Variable> VisitVariableSeq(List<Variable> variableSeq)
     {
-      //Contract.Requires(variableSeq != null);
       Contract.Ensures(Contract.Result<List<Variable>>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1227,7 +1167,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Cmd VisitAssertEnsuresCmd(AssertEnsuresCmd node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Cmd>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1235,7 +1174,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public override Cmd VisitAssertRequiresCmd(AssertRequiresCmd node)
     {
-      //Contract.Requires(node != null);
       Contract.Ensures(Contract.Result<Cmd>() != null);
       Contract.Assert(false);
       throw new Cce.UnreachableException();
@@ -1245,9 +1183,9 @@ namespace Microsoft.Boogie.VCExprAST
 
   /////////////////////////////////////////////////////////////////////////////////
 
-  public class IAppliableTranslator : IAppliableVisitor<VCExpr /*!*/>
+  public class IAppliableTranslator : IAppliableVisitor<VCExpr>
   {
-    private readonly Boogie2VCExprTranslator /*!*/
+    private readonly Boogie2VCExprTranslator
       BaseTranslator;
 
     [ContractInvariantMethod]
@@ -1257,7 +1195,7 @@ namespace Microsoft.Boogie.VCExprAST
     }
 
 
-    private VCExpressionGenerator /*!*/ Gen
+    private VCExpressionGenerator Gen
     {
       get
       {
@@ -1285,11 +1223,11 @@ namespace Microsoft.Boogie.VCExprAST
 
     ///////////////////////////////////////////////////////////////////////////////
 
-    private List<VCExpr /*!*/> /*!*/
-      args = new List<VCExpr /*!*/>();
+    private List<VCExpr>
+      args = new List<VCExpr>();
 
-    private List<Type /*!*/> /*!*/
-      typeArgs = new List<Type /*!*/>();
+    private List<Type>
+      typeArgs = new List<Type>();
 
     [ContractInvariantMethod]
     void ObjectInvarianet()
@@ -1299,7 +1237,7 @@ namespace Microsoft.Boogie.VCExprAST
     }
 
 
-    public VCExpr Translate(IAppliable app, Type ty, List<VCExpr /*!*/> /*!*/ args, List<Type /*!*/> /*!*/ typeArgs)
+    public VCExpr Translate(IAppliable app, Type ty, List<VCExpr> args, List<Type> typeArgs)
     {
       Contract.Requires(ty != null);
       Contract.Requires(app != null);
@@ -1307,14 +1245,14 @@ namespace Microsoft.Boogie.VCExprAST
       Contract.Requires(Cce.NonNullElements(args));
       Contract.Ensures(Contract.Result<VCExpr>() != null);
 
-      List<VCExpr /*!*/> /*!*/
+      List<VCExpr>
         oldArgs = this.args;
-      List<Type /*!*/> /*!*/
+      List<Type>
         oldTypeArgs = this.typeArgs;
       this.args = args;
       this.typeArgs = typeArgs;
-      VCExpr /*!*/
-        result = app.Dispatch<VCExpr /*!*/>(this);
+      VCExpr
+        result = app.Dispatch<VCExpr>(this);
       this.args = oldArgs;
       this.typeArgs = oldTypeArgs;
       return result;
@@ -1325,7 +1263,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public VCExpr Visit(UnaryOperator unaryOperator)
     {
-      //Contract.Requires(unaryOperator != null);
       Contract.Ensures(Contract.Result<VCExpr>() != null);
       Contract.Assert(unaryOperator.Op == UnaryOperator.Opcode.Neg || unaryOperator.Op == UnaryOperator.Opcode.Not);
       Contract.Assert(this.args.Count == 1);
@@ -1354,14 +1291,12 @@ namespace Microsoft.Boogie.VCExprAST
 
     public VCExpr Visit(BinaryOperator binaryOperator)
     {
-      //Contract.Requires(binaryOperator != null);
       Contract.Ensures(Contract.Result<VCExpr>() != null);
       return TranslateBinaryOperator(binaryOperator, this.args);
     }
 
     public VCExpr Visit(FunctionCall functionCall)
     {
-      //Contract.Requires(functionCall != null);
       Contract.Ensures(Contract.Result<VCExpr>() != null);
       return TranslateFunctionCall(functionCall, this.args, this.typeArgs);
     }
@@ -1386,7 +1321,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public VCExpr Visit(TypeCoercion typeCoercion)
     {
-      //Contract.Requires(typeCoercion != null);
       Contract.Ensures(Contract.Result<VCExpr>() != null);
       Contract.Assert(this.args.Count == 1);
       return this.args[0];
@@ -1394,7 +1328,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public VCExpr Visit(ArithmeticCoercion arithCoercion)
     {
-      //Contract.Requires(arithCoercion != null);
       Contract.Ensures(Contract.Result<VCExpr>() != null);
       Contract.Assert(this.args.Count == 1);
       switch (arithCoercion.Coercion)
@@ -1411,7 +1344,6 @@ namespace Microsoft.Boogie.VCExprAST
 
     public VCExpr Visit(IfThenElse ite)
     {
-      //Contract.Requires(ite != null);
       Contract.Ensures(Contract.Result<VCExpr>() != null);
       return Gen.Function(VCExpressionGenerator.IfThenElseOp, this.args);
     }
@@ -1447,7 +1379,7 @@ namespace Microsoft.Boogie.VCExprAST
     
     ///////////////////////////////////////////////////////////////////////////////
 
-    private VCExpr TranslateBinaryOperator(BinaryOperator app, List<VCExpr /*!*/> /*!*/ args)
+    private VCExpr TranslateBinaryOperator(BinaryOperator app, List<VCExpr> args)
     {
       Contract.Requires(app != null);
       Contract.Requires(Cce.NonNullElements(args));
@@ -1582,8 +1514,8 @@ namespace Microsoft.Boogie.VCExprAST
 
     ///////////////////////////////////////////////////////////////////////////////
 
-    private VCExpr /*!*/
-      TranslateFunctionCall(FunctionCall app, List<VCExpr /*!*/> /*!*/ args, List<Type /*!*/> /*!*/ typeArgs)
+    private VCExpr
+      TranslateFunctionCall(FunctionCall app, List<VCExpr> args, List<Type> typeArgs)
     {
       Contract.Requires(Cce.NonNullElements(args));
       Contract.Requires(Cce.NonNullElements(typeArgs));
@@ -1597,12 +1529,12 @@ namespace Microsoft.Boogie.VCExprAST
         return res;
       }
 
-      VCExprOp /*!*/
+      VCExprOp
         functionOp = Gen.BoogieFunctionOp(app.Func);
       return Gen.Function(functionOp, args, typeArgs);
     }
 
-    private VCExpr ApplyExpansion(FunctionCall app, List<VCExpr /*!*/> /*!*/ args, List<Type /*!*/> /*!*/ typeArgs)
+    private VCExpr ApplyExpansion(FunctionCall app, List<VCExpr> args, List<Type> typeArgs)
     {
       Contract.Requires(app != null);
       Contract.Requires(Cce.NonNullElements(args));
@@ -1617,9 +1549,9 @@ namespace Microsoft.Boogie.VCExprAST
           return null;
         }
 
-        VCExpr /*!*/
+        VCExpr
           translatedBody;
-        VCExprSubstitution /*!*/
+        VCExprSubstitution
           subst = new VCExprSubstitution();
         try
         {
@@ -1651,7 +1583,7 @@ namespace Microsoft.Boogie.VCExprAST
           subst[tparms[i]] = typeArgs[i];
         }
 
-        SubstitutingVCExprVisitor /*!*/
+        SubstitutingVCExprVisitor
           substituter = new SubstitutingVCExprVisitor(Gen);
         return substituter.Mutate(translatedBody, subst);
       }
